@@ -118,14 +118,14 @@ inline qreal lookupOutlineIntensity(int intensity)
     case Breeze::InternalSettings::OutlineLow:
         return 0.1;
     case Breeze::InternalSettings::OutlineMedium:
-        return 0.25;
+        return Breeze::Metrics::Bias_Default;
     case Breeze::InternalSettings::OutlineHigh:
         return 0.4;
     case Breeze::InternalSettings::OutlineMaximum:
         return 0.6;
     default:
         // Fallback to the Medium intensity.
-        return 0.2;
+        return Breeze::Metrics::Bias_Default;
     }
 }
 }
