@@ -68,7 +68,7 @@ void Animations::setupEngines()
     _toolBoxEngine->setDuration(animationsDuration);
 
     // registered engines
-    foreach (const BaseEngine::Pointer &engine, _engines) {
+    for (const BaseEngine::Pointer &engine : std::as_const(_engines)) {
         engine.data()->setEnabled(animationsEnabled);
         engine.data()->setDuration(animationsDuration);
     }
@@ -199,12 +199,12 @@ void Animations::unregisterWidget(QWidget *widget) const
     _widgetEnabilityEngine->unregisterWidget(widget);
     _spinBoxEngine->unregisterWidget(widget);
     _comboBoxEngine->unregisterWidget(widget);
-    _busyIndicatorEngine->registerWidget(widget);
+    _busyIndicatorEngine->unregisterWidget(widget);
 
     // the following allows some optimization of widget unregistration
     // it assumes that a widget can be registered atmost in one of the
     // engines stored in the list.
-    foreach (const BaseEngine::Pointer &engine, _engines) {
+    for (const BaseEngine::Pointer &engine : std::as_const(_engines)) {
         if (engine && engine.data()->unregisterWidget(widget)) {
             break;
         }
