@@ -1,6 +1,3 @@
-#ifndef breezeblurhelper_h
-#define breezeblurhelper_h
-
 //////////////////////////////////////////////////////////////////////////////
 // breezeblurhelper.h
 // handle regions passed to kwin for blurring
@@ -15,6 +12,8 @@
 // SPDX-License-Identifier: MIT
 //////////////////////////////////////////////////////////////////////////////
 
+#pragma once
+
 #include "breeze.h"
 #include "breezehelper.h"
 
@@ -53,5 +52,3 @@ protected:
 };
 
 }
-
-#endif
