@@ -26,6 +26,7 @@ class QStyleOptionSlider;
 
 namespace Breeze
 {
+class PaletteChangedEventFilter;
 //* breeze style helper class.
 /** contains utility functions used at multiple places in both breeze style and breeze window decoration */
 class Helper : public QObject
@@ -50,6 +51,12 @@ public:
     //* pointer to kdecoration config
     QSharedPointer<InternalSettings> decorationConfig() const;
 
+    //* install event filter for palette change event
+    void installEventFilter(QApplication *app) const;
+
+    //* uninstall event filter
+    void removeEventFilter(QApplication *app) const;
+
     //*@name color utilities
     //@{
 
@@ -93,7 +100,7 @@ public:
     }
 
     //* shadow
-    QColor shadowColor(const QPalette &palette, qreal opacity = 0.125) const
+    QColor shadowColor([[maybe_unused]] const QPalette &palette, qreal opacity = 0.125) const
     {
         return QColor::fromRgbF(0, 0, 0, opacity);
     }
@@ -195,7 +202,8 @@ public:
     void renderSidePanelFrame(QPainter *, const QRect &, const QColor &outline, Side) const;
 
     //* menu frame
-    void renderMenuFrame(QPainter *, const QRect &, const QColor &color, const QColor &outline, bool roundCorners = true, bool isTopMenu = false) const;
+    void renderMenuFrame(QPainter *, const QRect &, const QColor &color, const QColor &outline, bool roundCorners = true, Qt::Edges seamlessEdges = Qt::Edges())
+        const;
 
     //* button frame
     void renderButtonFrame(QPainter *painter,
@@ -363,6 +371,8 @@ public:
                         QIcon::Mode mode = QIcon::Normal,
                         QIcon::State state = QIcon::Off);
 
+    static Qt::Edges menuSeamlessEdges(const QWidget *);
+
 protected:
     //* return rounded path in a given rect, with only selected corners rounded, and for a given radius
     QPainterPath roundedPath(const QRectF &, Corners, qreal) const;
@@ -377,6 +387,9 @@ private:
     //* decoration configuration
     QSharedPointer<InternalSettings> _decorationConfig;
 
+    //* event filter
+    PaletteChangedEventFilter *_eventFilter;
+
     //*@name brushes
     //@{
     KStatefulBrush _viewFocusBrush;
@@ -398,6 +411,20 @@ private:
     mutable bool _cachedAutoValid = false;
 
     friend class ToolsAreaManager;
+    friend class PaletteChangedEventFilter;
 };
 
+class PaletteChangedEventFilter : public QObject
+{
+    Q_OBJECT
+
+public:
+    explicit PaletteChangedEventFilter(Helper *);
+
+protected:
+    bool eventFilter(QObject *watched, QEvent *event) override;
+
+private:
+    Helper *_helper;
+};
 }
